/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.jira.test;

import java.util.Arrays;

import org.sonatype.jira.AttachmentHandler;
import org.sonatype.jira.mock.MockAttachmentHandler;
import org.sonatype.jira.mock.StubJira;
import org.sonatype.tests.http.server.api.ServerProvider;
import org.sonatype.tests.http.server.jetty.impl.JettyServerProvider;

public class MockConfigurator
    implements JiraProxySuiteConfigurator
{

    private final StubJira mock;

    public MockConfigurator( final StubJira value )
        throws Exception
    {
        this.mock = value;
    }

    @Override
    public ServerProvider provider()
    {
        try
        {
            JettyServerProvider provider = new JettyServerProvider();
            MockAttachmentHandler mockAttachmentHandler = new MockAttachmentHandler();
            mockAttachmentHandler.setMock( mock );
            provider.addServlet( new JiraXmlRpcTestServlet( mock, provider.getUrl(),
                                                            Arrays.<AttachmentHandler> asList( mockAttachmentHandler ) ) );
            return provider;
        }
        catch ( Exception e )
        {
            throw new RuntimeException( e );
        }
    }

    @Override
    public String getName()
    {
        return "MOCK";
    }

    @Override
    public StubJira getHandler()
    {
        return mock;
    }

}
