/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.jira.test;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.Method;
import java.util.List;

import javax.inject.Inject;

import org.sonatype.inject.Sisu;
import org.sonatype.jira.AttachmentHandler;
import org.sonatype.jira.JiraXmlRpcProxy;
import org.sonatype.jira.recorder.Replayer;
import org.sonatype.tests.http.server.api.ServerProvider;
import org.sonatype.tests.http.server.jetty.impl.JettyServerProvider;

public class ReplayConfigurator
implements JiraProxySuiteConfigurator
{

    private final String prefix;

    private final File file;

    private final Replayer handler;

    @Inject
    private List<AttachmentHandler> handlers;

    public ReplayConfigurator( final String prefix, final Method method )
    {
        Sisu.inject( this );
        String path =
            String.format( "%s%s#%s.xml", prefix == null ? "" : prefix, method.getDeclaringClass().getName(),
                            method.getName() );
        this.file = new File( path );
        this.prefix = prefix;
        try
        {
            handler = new Replayer( file );
        }
        catch ( IOException e )
        {
            throw new RuntimeException( e );
        }
    }

    @Override
    public ServerProvider provider()
    {
        try
        {
            JettyServerProvider provider = new JettyServerProvider();
            provider.addServlet( new JiraXmlRpcTestServlet( handler, file.toURI().toURL(), handlers ) );
            return provider;
        }
        catch ( Exception e )
        {
            throw new RuntimeException( e );
        }
    }

    @Override
    public String getName()
    {
        return "REPLAY::" + prefix;
    }

    @Override
    public JiraXmlRpcProxy getHandler()
    {
        return handler;
    }

}
